/*
 * Copyright (c) 2003-2009 The Ochusha Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: misc_utils.c,v 1.16 2009/01/01 07:46:51 fuyu Exp $
 */

#include "config.h"

#include "libochushagtk/misc_utils.h"

#include <glib.h>
#include <gtk/gtk.h>

#include <stdio.h>


#if !GTK_CHECK_VERSION(2,14,0)
static GdkAtom text_uri_list_atom = NULL;


static void
init_atoms()
{
  if (text_uri_list_atom != NULL)
    return;

#if GTK_CHECK_VERSION(2,10,0)
  text_uri_list_atom = gdk_atom_intern_static_string("text/uri-list");
#else
  text_uri_list_atom = gdk_atom_intern("text/uri-list", FALSE);
#endif
}


/*
 * ĤAPIäơʤ̵
 * ġĤȻפäƤgtk+-2.14.0Ǥ褦䤯ɲä줿褦
 */
gchar **
ochusha_clipboard_wait_for_uris(GtkClipboard *clipboard)
{
  GtkSelectionData *data;
  gchar **uri_list;

  g_return_val_if_fail(GTK_IS_CLIPBOARD(clipboard), NULL);

  init_atoms();

  data = gtk_clipboard_wait_for_contents(clipboard, text_uri_list_atom);
  if (data == NULL)
    return NULL;

  uri_list = gtk_selection_data_get_uris(data);

  gtk_selection_data_free(data);

  return uri_list;
}


gboolean
ochusha_clipboard_wait_is_uris_available(GtkClipboard *clipboard)
{
  g_return_val_if_fail(GTK_IS_CLIPBOARD(clipboard), FALSE);

  init_atoms();

  return gtk_clipboard_wait_is_target_available(clipboard, text_uri_list_atom);
}
#endif
